#
# spec file for package silc-toolkit
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define so_ver 1_1-4

Name:           silc-toolkit
# NOTE: This package compiles only library and not client nor server.
Summary:        Secure Internet Live Conferencing Software Development Toolkit
Version:        1.1.12
Release:        5.12
License:        GPL-2.0 or BSD-3-Clause
Group:          System/Libraries
Url:            http://www.silcnet.org/dev.html
Source:         http://sourceforge.net/projects/silc/files/silc/toolkit/sources/%{name}-%{version}.tar.bz2
Patch1:         silc-buildroot.patch
Patch2:         silc-tutorial-makefile.patch
Patch3:         silc-ppc-return.patch
BuildRequires:  dante-devel 
BuildRequires:  libtool 
BuildRequires:  nasm
BuildRequires:  pam-devel
BuildRequires:  yasm
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SILC Toolkit is a software development toolkit which provides full SILC
protocol implementation for application developers. The SILC Toolkit
provides SILC Client Library, SILC Protocol Core Library, SILC Key
Exchange Library, SILC Crypto Library, SILC Math Library, SILC Utility
Library, as well as other libraries. The SILC Toolkit also includes a
full reference manual and developer guide with examples and tutorials.

SILC (Secure Internet Live Conferencing) is a protocol which provides
secure conferencing services on the Internet over insecure channels.
SILC is similar to IRC, as they both provide conferencing services and
almost have the same commands. However, they differ internally: unlike
IRC, SILC is secure and has an entirely different network model 
compared to IRC.

%package -n libsilc-%{so_ver}
Group:          System/Libraries
Summary:        Secure Internet Live Conferencing Software Development Toolkit
# NOTE: library does not require modules, but any client software may use SILC_MODULESDIR:
Requires:       %{name} >= %{version}

%description -n libsilc-%{so_ver}
SILC Toolkit is a software development toolkit which provides full SILC
protocol implementation for application developers. The SILC Toolkit
provides SILC Client Library, SILC Protocol Core Library, SILC Key
Exchange Library, SILC Crypto Library, SILC Math Library, SILC Utility
Library, and other libraries. The SILC Toolkit also includes full
reference manual and developer guide with examples and tutorials.

SILC (Secure Internet Live Conferencing) is a protocol which provides
secure conferencing services on the Internet over insecure channel.
SILC is IRC-like software although internally they are very different.
The biggest similarity between SILC and IRC is that they both provide
conferencing services and that SILC has almost the same commands as
IRC. Other than that they are nothing alike.  Major differences are
that SILC is secure what IRC is not in any way.  The network model is
also entirely different compared to IRC.

%package -n libsilcclient-%{so_ver}
Group:          System/Libraries
Summary:        Secure Internet Live Conferencing Software Development Toolkit
# NOTE: library does not require modules, but any client software may use SILC_MODULESDIR:
Requires:       %{name} >= %{version}

%description -n libsilcclient-%{so_ver}
SILC Toolkit is a software development toolkit which provides full SILC
protocol implementation for application developers. The SILC Toolkit
provides SILC Client Library, SILC Protocol Core Library, SILC Key
Exchange Library, SILC Crypto Library, SILC Math Library, SILC Utility
Library, and other libraries. The SILC Toolkit also includes full
reference manual and developer guide with examples and tutorials.

SILC (Secure Internet Live Conferencing) is a protocol which provides
secure conferencing services on the Internet over insecure channel.
SILC is IRC-like software although internally they are very different.
The biggest similarity between SILC and IRC is that they both provide
conferencing services and that SILC has almost the same commands as
IRC. Other than that they are nothing alike.  Major differences are
that SILC is secure what IRC is not in any way.  The network model is
also entirely different compared to IRC.

%package devel
Group:          System/Libraries
Summary:        Secure Internet Live Conferencing Software Development Toolkit
Requires:       libsilc-%{so_ver} = %{version} 
Requires:       libsilcclient-%{so_ver} = %{version}
Requires:       dante-devel

%description devel
SILC Toolkit is a software development toolkit which provides full SILC
protocol implementation for application developers. The SILC Toolkit
provides SILC Client Library, SILC Protocol Core Library, SILC Key
Exchange Library, SILC Crypto Library, SILC Math Library, SILC Utility
Library, and other libraries. The SILC Toolkit also includes full
reference manual and developer guide with examples and tutorials.

SILC (Secure Internet Live Conferencing) is a protocol which provides
secure conferencing services on the Internet over insecure channel.
SILC is IRC-like software although internally they are very different.
The biggest similarity between SILC and IRC is that they both provide
conferencing services and that SILC has almost the same commands as
IRC. Other than that they are nothing alike.  Major differences are
that SILC is secure what IRC is not in any way.  The network model is
also entirely different compared to IRC.

%prep
%setup -q
%patch1
%patch2
%patch3 -p1

%build
ACLOCAL="aclocal -I ." autoreconf -f -i
# If it compiles OK, do not use --with-gmp. See INSTALL for more.
%configure\
	--includedir=%{_includedir}/silc\
	--docdir=%{_docdir}/%{name}\
	--with-simdir=%{_libdir}/silc/modules\
	--with-socks4 --disable-static --with-pic --without-libtoolfix
make %{?jobs:-j%jobs}

%install
%makeinstall
rm $RPM_BUILD_ROOT%{_docdir}/%{name}/{INSTALL,README.MACOSX,README.SYMBIAN,README.WIN32}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/silc
cp doc/silcalgs.conf $RPM_BUILD_ROOT%{_sysconfdir}/silc/
%{__rm} -f %{buildroot}%{_libdir}/*.la

%post -n libsilc-%{so_ver} -p /sbin/ldconfig

%postun -n libsilc-%{so_ver} -p /sbin/ldconfig

%post -n libsilcclient-%{so_ver} -p /sbin/ldconfig

%postun -n libsilcclient-%{so_ver} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/BSD
%{_docdir}/%{name}/ChangeLog
%{_docdir}/%{name}/COPYING
%{_docdir}/%{name}/CREDITS
%{_docdir}/%{name}/FAQ
%{_docdir}/%{name}/GPL
%{_docdir}/%{name}/README
%{_docdir}/%{name}/TODO
%{_libdir}/silc
%{_sysconfdir}/silc

%files -n libsilc-%{so_ver}
%defattr(-,root,root)
%{_libdir}/libsilc-1.1.so.4*

%files -n libsilcclient-%{so_ver}
%defattr(-,root,root)
%{_libdir}/libsilcclient-1.1.so.4*

%files devel
%defattr(-,root,root)
%{_docdir}/%{name}/CodingStyle
%{_docdir}/%{name}/*.txt
%{_docdir}/%{name}/toolkit
%{_docdir}/%{name}/tutorial
%{_includedir}/silc
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Mar 24 2015 p.drouand@gmail.com
- Update to version 1.12
  * This version adds support for associating the client or server entry
    with the public key verification callback allowing application to
    show more information about the entity whose public key it is
    verifying.
  * fixes some minor bugs.
- Remove depreciated AUTHORS and %%clean section
- Update project and download Urls
- Bump libsilc and libsilcclient so versions to 1_1-4
- Some other little improvements
- Add pam-devel build require; fix build on SLE11
* Mon Jul 16 2012 cfarrell@suse.com
- license update: GPL-2.0 or BSD-3-Clause
  Package uses GPL-2.0 (only) as the GPL side of the dual license option
* Mon May 28 2012 dvaleev@suse.com
- fix ppc build
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Aug 30 2011 andrea.turrini@gmail.com
- Fixed incomplete sentence following other descriptions in
  silc-toolkit.spec
* Tue Sep  1 2009 sbrabec@suse.cz
- Updated to version 1.1.10:
  * Fixed format string arbitrary execution errors (bnc#535841).
  * Fixed stack overwrite due to format string error on x86_64
    (bnc#535841).
  * Fixed IDENTIFY, DETACH, IDENTIFY and SIGNOFF behavior.
  * Fixed Deny hostname comparison.
  * Debugging fixes.
* Tue Aug 11 2009 sbrabec@suse.cz
- Updated to version 1.1.9:
  * memory allocation fixes
  * debugging messages fixes
  * library linking fix
- Split package according to shared library policy.
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Wed Apr 16 2008 schwab@suse.de
- Fix use of libtool.
* Wed Mar 26 2008 sbrabec@suse.cz
- Updated to version 1.1.7:
  * Fixed silcd crash in NEW_CLIENT packet handling when nickname
    is not present in the packet (bnc#373927, CORE-2007-1212,
    Bugtraq#28373, CWE#196).
* Tue Mar 11 2008 sbrabec@suse.cz
- Updated to version 1.1.6:
  * Fixed printable fingerprint buffer overflow (bnc#369067,
    CVE-2008-1227).
  * Many minor fixes and improvements, see CHANGES for more.
* Mon Nov 26 2007 sbrabec@suse.cz
- Work-around missing docdir support in older SuSE versions.
* Mon Aug 13 2007 schwab@suse.de
- Fix syntax error.
* Thu Jul 26 2007 sbrabec@suse.cz
- Updated to version 1.1.2:
  * Fixed buffer overflow with NICK_CHANGE notify in client
    library.
  * Fixed silc_client_free early crash.
  * Fixred PFS rekey with CTR mode.
  * Fixed packet flags unsetting.
  * Added silc_idcache_move function.
  * Other fixes were also made.
* Tue May 15 2007 sbrabec@suse.cz
- New SuSE package, version 1.0.2 (compatible with pidgin-2.0.0).
